apc.indiv.compare.direct <- function(data, big.model, small.model, unit=1,
                                     dep.var, covariates=NULL, model.family,
                                     n.coh.excl.start=0, n.coh.excl.end=0,
                                     n.age.excl.start=0, n.age.excl.end=0,
                                     n.per.excl.start=0, n.per.excl.end=0,
                                     NR.controls=NULL){
  # Check that family is correctly specified
  family.list <- c("gaussian", "binomial")
  if (!isTRUE(model.family %in% c(family.list)))
    stop("model.family not recognised")
  
  # Check that all models are correctly specified
  design.list <- c("APC", "AP", "AC", "PC", "Ad", "Pd", "Cd", "A",
                   "P", "C", "t", "tA", "tP", "tC", "1")
  if (!isTRUE(big.model %in% c(design.list, "TS")))
    stop("big.model not recognised")
  if (!isTRUE(small.model %in% design.list))
    stop("small.model not recognised; TS cannot be small.model")
  
  # For the gaussian family, use an Ftest
  if (model.family == "gaussian"){
    if (big.model %in% design.list){
      test <- apc.indiv.ftest.fullapc(data = data, big.model = big.model,
                                      small.model = small.model,
                                      dep.var = dep.var, covariates = covariates,
                                      unit = unit,
                                      n.coh.excl.start = n.coh.excl.start,
                                      n.coh.excl.end = n.coh.excl.end,
                                      n.age.excl.start = n.age.excl.start,
                                      n.age.excl.end = n.age.excl.end,
                                      n.per.excl.start = n.per.excl.start,
                                      n.per.excl.end = n.per.excl.end)
    } else if (big.model == "TS"){
      test <- apc.indiv.ftest.TS(data = data, small.model = small.model,
                                 dep.var = dep.var, covariates = covariates,
                                 unit = unit, 
                                 n.coh.excl.start = n.coh.excl.start,
                                 n.coh.excl.end = n.coh.excl.end,
                                 n.age.excl.start = n.age.excl.start,
                                 n.age.excl.end = n.age.excl.end,
                                 n.per.excl.start = n.per.excl.start,
                                 n.per.excl.end = n.per.excl.end)
    }
  }
  # For the binomial family, use likelihood ratio tests
  if (model.family == "binomial"){
    if (big.model %in% design.list){
      test <- apc.indiv.LRtest.fullapc(data = data, big.model = big.model,
                                       small.model = small.model,
                                       dep.var = dep.var, covariates = covariates,
                                       unit = unit,
                                       n.coh.excl.start = n.coh.excl.start,
                                       n.coh.excl.end = n.coh.excl.end,
                                       n.age.excl.start = n.age.excl.start,
                                       n.age.excl.end = n.age.excl.end,
                                       n.per.excl.start = n.per.excl.start,
                                       n.per.excl.end = n.per.excl.end)
    } else if (big.model == "TS"){
      # Specify defaults to control Newton-Rhapson of time-saturated model
      if (is.null(NR.controls$maxit.loop)) NR.controls$maxit.loop <- 10
      if (is.null(NR.controls$maxit.linesearch)) 
        NR.controls$maxit.linesearch <- 30
      if (is.null(NR.controls$init)) NR.controls$init <- "ols"
      test <- apc.indiv.LRtest.TS(data = data, small.model = small.model,
                                  dep.var = dep.var, covariates = covariates,
                                  unit = unit, 
                                  n.coh.excl.start = n.coh.excl.start,
                                  n.coh.excl.end = n.coh.excl.end,
                                  n.age.excl.start = n.age.excl.start,
                                  n.age.excl.end = n.age.excl.end,
                                  n.per.excl.start = n.per.excl.start,
                                  n.per.excl.end = n.per.excl.end,
                                  maxit.loop.TS = NR.controls$maxit.loop,
                                  maxit.linesearch.TS = 
                                    NR.controls$maxit.linesearch,
                                  init.TS = NR.controls$init)
    }
  }
  return(test)
}