apc.indiv.model.table <- function(data, dep.var, covariates = NULL, unit=1,
                                  n.coh.excl.start = 0, n.coh.excl.end = 0,
                                  n.age.excl.start = 0, n.age.excl.end = 0,
                                  n.per.excl.start = 0, n.per.excl.end = 0,
                                  model.family=NULL, NR.controls = NULL){
  # Check that family is correctly specified
  family.list <- c("gaussian", "binomial")
  if (!isTRUE(model.family %in% c(family.list)))
    stop("model.family not recognised")
  
  # For the gaussian family, use an Ftable
  if (model.family == "gaussian") 
    table <- apc.indiv.ftable(data = data, dep.var = dep.var, unit = unit,
                              covariates = covariates,
                              n.coh.excl.start = n.coh.excl.start,
                              n.coh.excl.end = n.coh.excl.end,
                              n.age.excl.start = n.age.excl.start,
                              n.age.excl.end = n.age.excl.end,
                              n.per.excl.start = n.per.excl.start,
                              n.per.excl.end = n.per.excl.end)
  # For the binomial family, use an LR table
  if (model.family == "binomial"){
    # Specify defaults to control Newton-Rhapson of time-saturated model
    if (is.null(NR.controls$maxit.loop)) NR.controls$maxit.loop <- 10
    if (is.null(NR.controls$maxit.linesearch)) 
      NR.controls$maxit.linesearch <- 30
    if (is.null(NR.controls$init)) NR.controls$init <- "ols"
    table <- apc.indiv.LRtable.TS(data = data, dep.var = dep.var, unit = unit,
                                  covariates = covariates,
                                  n.coh.excl.start = n.coh.excl.start,
                                  n.coh.excl.end = n.coh.excl.end,
                                  n.age.excl.start = n.age.excl.start,
                                  n.age.excl.end = n.age.excl.end,
                                  n.per.excl.start = n.per.excl.start,
                                  n.per.excl.end = n.per.excl.end,
                                  maxit.loop.TS = NR.controls$maxit.loop,
                                  maxit.linesearch.TS = 
                                    NR.controls$maxit.linesearch,
                                  init.TS = NR.controls$init)
  }
  return(table)
}